import argparse
from .util import *


def main():
    parser = argparse.ArgumentParser(description="Juggling with hex")
    parser.add_argument("input", help="Input")
    parser.add_argument("-r", action="store_true", help="reverse")
    args = parser.parse_args()

    if args.r:
        print(from_hex(args.input))
    else:
        output = normalize_to_hex(args.input)
        print(output)


if __name__ == "__main__":
    main()



import sys


def normalize_to_hex(input):
    if input in [".0", "0."]:
        return "0x0"
    elif (
        ("e" in input or "E" in input)
        and (float(input) >= 1 or float(input) == 0)
        and not ("e0" in input or "E0" in input)
    ):
        try:
            return hex(int(float(input)))
        except ValueError as ve:
            print(ve)
    else:
        try:
            return hex(int(input))
        except ValueError:
            try:
                output = float.hex(float(input))
                out_arr = output.split("p")
                out_arr[0] = out_arr[0].rstrip("0")
                out_arr[1] = out_arr[1].lstrip("+")
                output = out_arr[0] + "p" + out_arr[1]
                return output
            except ValueError as ve:
                print(ve)


def from_hex(input):
    try:
        output = float.fromhex(input)
        return f"{output:f}".rstrip("0").rstrip(".")
    except ValueError as ve:
        print(ve)
    except OverflowError as oe:
        print(oe)



import pathlib
from setuptools import setup

HERE = pathlib.Path(__file__).parent
README = (HERE / "README.md").read_text()

setup(
    name="frash",
    version="0.0.6",
    description="Juggling with hex numbers. Convert integers and floats to hex.",
    long_description=README,
    long_description_content_type="text/markdown",
    url="https://github.com/0xflotus/frash",
    author="0xflotus",
    author_email="0xflotus+pypi@gmail.com",
    license="MIT",
    classifiers=[
        "Development Status :: 4 - Beta",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.9",
        "Topic :: Software Development :: Libraries ",
    ],
    packages=["frash"],
    include_package_data=True,
    install_requires=["argparse"],
    tests_require=["pytest"],
    entry_points={
        'console_scripts': [
            'frash=frash.__main__:main'
        ]
    }
)

